/*
 * Copyright (C) 2006 Andre Noll <maan@systemlinux.org>
 *
 * Licensed under the GPL v2. For licencing details see COPYING.
 */

/** \file grab_client.h exported symbols from grab_client.c */

#include "config.h"
/**
 * handle blocking writes for the grab client fds
 *
 * - pedantic: close fd if write would block
 * - sloppy: ignore the data and do not write
 * - aggressive: write anyway (default)
 *
 */
enum grab_mode {GRAB_SLOPPY, GRAB_AGGRESSIVE, GRAB_PEDANTIC};

/** describes one active grab client
 *
 * \sa filter_callback, filter_node::callbacks
 */
struct grab_client {
/** the file descriptor to send the grabbed stream to */
	int fd;
/** the command line options for this grab client */
	struct grab_client_args_info *conf;
/** pedantic, sloppy, or aggressive, computed from command line */
	enum grab_mode mode;
/** non-zero if the write() to \a fd failed */
	int error;
/** the number of the desired audio format, computed from command line */
	int audio_format_num;
/** the callback data which gets attached to a suitable filter_node */
	struct filter_callback fcb;
/** all grab clients belong either to a filter node or to the inactive list */
	struct list_head node;
/** the number of command line options */
	int argc;
/** pointers to the command line options */
	char **argv;
};

__malloc struct grab_client *grab_client_new(int fd, char *line, int *err);
void activate_inactive_grab_clients(int slot_num, int audio_format_num,
		struct filter_chain *fc);
void activate_grab_client(struct grab_client *gc, struct filter_node *fn);
void init_grabbing(void);
