/*
 * Copyright (C) 2006-2008 Andre Noll <maan@systemlinux.org>
 *
 * Licensed under the GPL v2. For licencing details see COPYING.
 */

/** \file string.h exported sybmols from string.c */

/** A string buffer used for para_printf(). */
struct para_buffer {
	/** The buffer. May be \p NULL. */
	char *buf;
	/** The size of \a buf. */
	size_t size;
	/** The maximal size this buffer may grow. Zero means unlimited. */
	size_t max_size;
	/** The next para_printf() will write at this offset. */
	size_t offset;
	/**
	 * If an attempt to print into this buffer is made that would need to
	 * grow \a buf to a size larger than \a max_size, then this function is
	 * called.
	 */
	int (*max_size_handler)(char *buf, size_t size, void *private_data);
	/** Passed to max_size_handler(). */
	void *private_data;
};

__must_check __malloc void *para_realloc(void *p, size_t size);
__must_check __malloc void *para_malloc(size_t size);
__must_check __malloc void *para_calloc(size_t size);
__must_check __malloc char *para_strdup(const char *s);
__must_check __malloc __printf_1_2 char *make_message(const char *fmt, ...);
__must_check __malloc char *para_strcat(char *a, const char *b);
__must_check __malloc char *para_dirname(const char *name);
__must_check const char *para_basename(const char *name);
void chop(char *buf);
__must_check __malloc char *para_tmpname(void);
__must_check __malloc char *para_logname(void);
__must_check __malloc char *para_homedir(void);
__must_check unsigned split_args(char *args, char *** const argv_ptr, const char *delim);
__malloc char *para_hostname(void);
void valid_fd_012(void);
__printf_2_3 int para_printf(struct para_buffer *b, const char *fmt, ...);
/** Used for for_each_line() and for_each_line_ro(). */
typedef int line_handler_t(char *, void *);
int for_each_line(char *buf, size_t size, line_handler_t *line_handler,
	void *private_data);
int for_each_line_ro(char *buf, size_t size, line_handler_t *line_handler,
	void *private_data);
int para_atoi64(const char *str, int64_t *result);
int para_atoi32(const char *str, int32_t *value);
